@@ -16,10 +16,21 @@ class TfState:
     represents a terraform state
     """
 
-    def __init__(self, path: Union[str, Path]):
+    def __init__(self, path: Union[str, Path], verbose=False):
         self.home_path = Path(path)
         self._local_state_path: Optional[Path] = None
         self._tf_client = TfClient(self.home_path)
+        self.verbose = verbose
+
+    @property
+    def verbose(self) -> bool:
+        """set the state verbosity"""
+        return self._verbose
+
+    @verbose.setter
+    def verbose(self, value: bool) -> None:
+        self._verbose = value
+        self._tf_client.verbose = value
 
     @property
     def local_state_path(self) -> Path:
@@ -32,8 +43,6 @@ class TfState:
         """Pulls the remote state to a local file (created in home directory if none is given)"""
         if state_file is not None:
             self._local_state_path = state_file
-        if self.local_state_path.exists():
-            raise FileExistsError(f"state '{self.home_path}' already has a local file, call `clean` first")
         self._tf_client.state_pull(self.local_state_path)
 
     def push(self) -> None:
@@ -63,7 +72,7 @@ class TfState:
             raise FileNotFoundError(f"source state '{self.home_path}' has no local state file, call `pull` first")
         if not dest.local_state_path.exists():
             raise FileNotFoundError(f"dest state '{self.home_path}' has no local state file, call `pull` first")
-        opts = "-dry-run" if dry_run else ""
+        opts = " -dry-run" if dry_run else ""
         self._tf_client.state_mv(self.local_state_path, dest.local_state_path, from_object, to_object, opts)
 
 
@@ -75,7 +84,6 @@ def filter_and_rename(items: List[str], prefix: str, new_prefix: str) -> Tuple[L
     :return: tuple (filtered_items, renamed_items)
     """
     # """"""
-    # prefix = f"{prefix}."
     from_items, to_items, duplicates = [], [], []
     for item in items:
         if item == prefix or item.startswith(f'{prefix}.'):
